import { createContext, useState, useReducer } from "react";
import { useDispatch } from "react-redux";
import fetcher from "../api/fetcher";
import { config } from "../config";
import { baseURLIdentifiers } from "../constants/baseURLIdentifiers";
import { SET_USER_DATA } from "../constants/types";

const authReducer = (state, action) => {
  switch (action.type) {
    case "LOGIN":
      return { ...state, isLoggedIn: true };
    case "LOGOUT":
      return { ...state, isLoggedIn: false };
    default:
      return state;
  }
};

const AuthContext = createContext();

const Auth = (props) => {
  const dispatch = useDispatch();

  const [state, authDispatch] = useReducer(authReducer, {
    isLoggedIn: false
  });

  const [isLoggedIn, setIsLoggedIn] = useState(false);

  const signup = async (email, password, name) => {
    const url = `${
                config[baseURLIdentifiers.USER_SERVICE]
              }/api/v1/user/register`;
    const body = {
      email: email,
      password: password,
      fullName: name
    };

    return await new Promise((resolve, reject) => {
      fetcher.post(url, body).then(
        (resp) => {
          resolve(resp);
      }).catch(
        (reason) => {
          reject(reason.response.data)
        }
      );
    });
  };

  const authenticate = async (email, password) => {
    const url = `${
      config[baseURLIdentifiers.USER_SERVICE]
    }/api/v1/user/login`;
    const body = {
      email: email,
      password: password
    };

    return await new Promise((resolve, reject) => {
      fetcher.post(url, body).then(
        (resp) => {
          const token = resp.data.data;
          setToken(token);
          authDispatch({ type: "LOGIN" });
          dispatch({
            type: SET_USER_DATA,
            payload: token
          });
          resolve(token);
        }
      ).catch(
        (reason => {
          localStorage.removeItem("token");
          reject(reason.response.data);
        })
      )
    });
  };

  const getSession = async (email, password) => {
    return await new Promise((resolve, reject) => {
      const tokenObj = getTokenObj();
      if (tokenObj) {
        dispatch({
          type: SET_USER_DATA,
          payload: tokenObj
        });
        resolve(tokenObj);
      } else {
        reject();
      }
    });
  };

  const setToken = (data) => {
    localStorage.setItem("token", btoa(JSON.stringify(data)));
  }

  const getTokenObj = () => {
    const lsToken = localStorage.getItem("token");
    if (lsToken && lsToken.trim() !== '') {
      const tokenObj = JSON.parse(atob(lsToken));
      return tokenObj;
    }
    return null;
  }

  const logout = () => {
    // setIsLoggedIn(false);
    authDispatch({ type: "LOGOUT" });
    localStorage.removeItem("token");
  };

  return (
    <AuthContext.Provider
      value={{ signup, authenticate, getSession, logout, getTokenObj, isLoggedIn: state.isLoggedIn }}
    >
      {props.children}
    </AuthContext.Provider>
  );
};

export { Auth, AuthContext };
