import { useEffect, useState, useMemo } from "react";

const DEBOUNCE_TIMEOUT = 300;

export default function useLocalStorage(key, initialValue) {
  const [value, setValue] = useState(() => {
    const jsonValue = localStorage.getItem(key);
    if (jsonValue != null) return JSON.parse(jsonValue);
    return initialValue;
  });

  const serializedValue = useMemo(() => JSON.stringify(value), [value]);

  const debouncedSetItem = useMemo(() => {
    let timeoutId;
    return (key, value) => {
      clearTimeout(timeoutId);
      timeoutId = setTimeout(() => {
        localStorage.setItem(key, value);
      }, DEBOUNCE_TIMEOUT);
    };
  }, []);

  useEffect(() => {
    debouncedSetItem(key, serializedValue);
    return () => {
      clearTimeout(debouncedSetItem);
    };
  }, [key, serializedValue, debouncedSetItem]);

  return [value, setValue];
}
